summaryrefslogtreecommitdiffstats
path: root/perform/pio_perf.h
diff options
context:
space:
mode:
Diffstat (limited to 'perform/pio_perf.h')
-rw-r--r--perform/pio_perf.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/perform/pio_perf.h b/perform/pio_perf.h
index 83ab7d9..e812f16 100644
--- a/perform/pio_perf.h
+++ b/perform/pio_perf.h
@@ -34,9 +34,10 @@ typedef struct parameters_ {
size_t block_size; /* interleaved block size */
hsize_t h5_align; /* HDF5 object alignment */
hsize_t h5_thresh; /* HDF5 object alignment threshold */
- unsigned h5_use_chunks; /* Make HDF5 dataset chunked */
- unsigned h5_no_fill; /* Disable HDF5 writing fill values */
- unsigned h5_write_only; /* Perform the write tests only */
+ int h5_use_chunks; /* Make HDF5 dataset chunked */
+ int h5_no_fill; /* Disable HDF5 writing fill values */
+ int h5_write_only; /* Perform the write tests only */
+ int verify; /* Verify data correctness */
} parameters;
typedef struct results_ {